"use strict";
/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMDXLoaderItem = createMDXLoaderItem;
exports.createMDXLoaderRule = createMDXLoaderRule;
const processor_1 = require("./processor");
async function enhancedOptions(options) {
    // Because Jest doesn't like ESM / createProcessors()
    if (process.env.N0DE_ENV === 'test' || process.env.JEST_WORKER_ID) {
        return options;
    }
    // We create the processor earlier here, to avoid the lazy processor creating
    // Lazy creation messes-up with Rsdoctor ability to measure mdx-loader perf
    const newOptions = options.processors
        ? options
        : { ...options, processors: await (0, processor_1.createProcessors)({ options }) };
    return newOptions;
}
async function createMDXLoaderItem(options) {
    return {
        loader: require.resolve('@docusaurus/mdx-loader'),
        options: await enhancedOptions(options),
    };
}
async function createMDXLoaderRule({ include, options, }) {
    return {
        test: /\.mdx?$/i,
        include,
        use: [await createMDXLoaderItem(options)],
    };
}
//# sourceMappingURL=createMDXLoader.js.map